"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.register = register;
exports.plugin = void 0;

var buildPaths = require('mwp-config').paths;

var path = require('path');
/*
 * The service worker plugin will register a root-level route for serving the
 * service worker script file.
 *
 * Disk location of the script file is determined by builder CLI config import.
 */


function register(server, options) {
  /*
   * Route for service worker script at top-level path. Depends on `Inert`
   * `path` must match client `serviceWorker.register` call - MWP provides this
   * in the `<ServiceWorker>` component
   */
  server.route({
    method: 'GET',
    path: '/asset-service-worker.{localeCode}.js',
    options: {
      auth: false
    },
    handler: function handler(request, h) {
      var localeCode = request.params.localeCode;
      var swPath = path.resolve(buildPaths.output.browser, localeCode, 'asset-service-worker.js');
      return h.file(swPath);
    }
  });
}

var plugin = {
  register: register,
  name: 'mwp-service-worker',
  version: '1.0.0',
  dependencies: 'inert' // decorates `h.file`

};
exports.plugin = plugin;
//# sourceMappingURL=index.js.map